@@ -213,7 +213,7 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         *,
         applicationComponentCriteria: ApplicationComponentCriteriaType = ...,
         filterValue: str = ...,
-        groupIdFilter: Sequence["GroupTypeDef"] = ...,
+        groupIdFilter: Sequence[GroupTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...,
         sort: SortOrderType = ...
@@ -249,7 +249,7 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         self,
         *,
         filterValue: str = ...,
-        groupIdFilter: Sequence["GroupTypeDef"] = ...,
+        groupIdFilter: Sequence[GroupTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...,
         serverCriteria: ServerCriteriaType = ...,
@@ -265,9 +265,9 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
     def put_portfolio_preferences(
         self,
         *,
-        applicationPreferences: "ApplicationPreferencesTypeDef" = ...,
-        databasePreferences: "DatabasePreferencesTypeDef" = ...,
-        prioritizeBusinessGoals: "PrioritizeBusinessGoalsTypeDef" = ...
+        applicationPreferences: ApplicationPreferencesTypeDef = ...,
+        databasePreferences: DatabasePreferencesTypeDef = ...,
+        prioritizeBusinessGoals: PrioritizeBusinessGoalsTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Saves the specified migration and modernization preferences.
@@ -293,7 +293,7 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         name: str,
         s3key: str,
         dataSourceType: DataSourceTypeType = ...,
-        groupId: Sequence["GroupTypeDef"] = ...,
+        groupId: Sequence[GroupTypeDef] = ...,
         s3bucketForReportData: str = ...
     ) -> StartImportFileTaskResponseTypeDef:
         """
@@ -304,7 +304,7 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         """
 
     def start_recommendation_report_generation(
-        self, *, groupIdFilter: Sequence["GroupTypeDef"] = ..., outputFormat: OutputFormatType = ...
+        self, *, groupIdFilter: Sequence[GroupTypeDef] = ..., outputFormat: OutputFormatType = ...
     ) -> StartRecommendationReportGenerationResponseTypeDef:
         """
         Starts generating a recommendation report.
@@ -327,8 +327,8 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         applicationComponentId: str,
         inclusionStatus: InclusionStatusType = ...,
         secretsManagerKey: str = ...,
-        sourceCodeList: Sequence["SourceCodeTypeDef"] = ...,
-        strategyOption: "StrategyOptionTypeDef" = ...
+        sourceCodeList: Sequence[SourceCodeTypeDef] = ...,
+        strategyOption: StrategyOptionTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Updates the configuration of an application component.
@@ -338,7 +338,7 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         """
 
     def update_server_config(
-        self, *, serverId: str, strategyOption: "StrategyOptionTypeDef" = ...
+        self, *, serverId: str, strategyOption: StrategyOptionTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Updates the configuration of the specified server.
