@@ -69,7 +69,7 @@ class GetServerDetailsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, serverId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, serverId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetServerDetailsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.GetServerDetails.paginate)
@@ -88,9 +88,9 @@ class ListApplicationComponentsPaginator(Boto3Paginator):
         *,
         applicationComponentCriteria: ApplicationComponentCriteriaType = ...,
         filterValue: str = ...,
-        groupIdFilter: Sequence["GroupTypeDef"] = ...,
+        groupIdFilter: Sequence[GroupTypeDef] = ...,
         sort: SortOrderType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListApplicationComponentsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.ListApplicationComponents.paginate)
@@ -105,7 +105,7 @@ class ListCollectorsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListCollectorsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.ListCollectors.paginate)
@@ -120,7 +120,7 @@ class ListImportFileTaskPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListImportFileTaskResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.ListImportFileTask.paginate)
@@ -138,10 +138,10 @@ class ListServersPaginator(Boto3Paginator):
         self,
         *,
         filterValue: str = ...,
-        groupIdFilter: Sequence["GroupTypeDef"] = ...,
+        groupIdFilter: Sequence[GroupTypeDef] = ...,
         serverCriteria: ServerCriteriaType = ...,
         sort: SortOrderType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.ListServers.paginate)
